componenttools.partition_components_by_durations_not_greater_than
=================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_by_durations_not_greater_than.partition_components_by_durations_not_greater_than
   :noindex:
